package ovh.herisson.Clyde.Repositories.ScientificPublications;

/******************************************************
 * @file StatsRepository.java
 * @author Bartha Maxime
 * @scope Publications Scientifiques
 *
 * Repository handling communication with Reseach table for making statistics
 ******************************************************/
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.CrudRepository;
import ovh.herisson.Clyde.Tables.ScientificPublications.Research;

import java.util.Map;

public interface StatsRepository extends CrudRepository<Research,Long> {

    @Query("select new map(to_char(r.releaseDate, 'month') as label, sum(r.views) as y) from Research r where r.author.id = ?1 group by to_char(r.releaseDate, 'month')")
    Iterable<Map<String ,Integer>> viewsByMonths(long researcherId);

    @Query("select new map(to_char(r.releaseDate,'YYYY') as label, sum  (r.views) as y) from Research r group by to_char(r.releaseDate,'YYYY')")
    Iterable<Map<String ,Integer>> viewsByYears(long researcherId);


    @Query("select new map(r.domain as label, sum(r.views) as y) from Research r where r.author.id = ?1 group by r.domain")
    Iterable<Map<String ,Integer>> viewsByTopics(long researcherId);


    @Query("select new map(r.domain as label, count(distinct r.language) as y) from Research r where r.author.id = ?1 group by r.domain")
    Iterable<Map<String ,Integer>> languageByTopics(long researcherId);

    @Query("select new map(to_char(r.releaseDate,'YYYY') as label,  count(distinct r.language) as y) from Research r where r.author.id = ?1 group by to_char(r.releaseDate,'YYYY')")
    Iterable<Map<String ,Integer>> languageByYears(long researcherId);

    @Query("select new map(to_char(r.releaseDate, 'month') as label, count(distinct r.language) as y) from Research r where r.author.id = ?1 group by to_char(r.releaseDate, 'month')")
    Iterable<Map<String ,Integer>> languageByMonths(long researcherId);

    @Query("select new map(to_char(r.releaseDate,'YYYY') as label, count(distinct r) as y) from Research r where r.author.id = ?1 group by to_char(r.releaseDate,'YYYY')")
    Iterable<Map<String ,Integer>> researchesByYears(long researcherId);

    @Query("select new map(r.domain as label, count(distinct r) as y) from Research r where r.author.id = ?1 group by r.domain")
    Iterable<Map<String ,Integer>> researchesByTopics(long researcherId);

    @Query("select new map(to_char(r.releaseDate, 'month') as label, count(distinct r) as y) from Research r where r.author.id = ?1 group by to_char(r.releaseDate, 'month')")
    Iterable<Map<String ,Integer>> researchesByMonth(long researcherId);

}
